package at.gv.egiz.moazs.util;

import java.util.Optional;

import static java.util.Optional.ofNullable;

/**
 * Helper function for coalescing nullables value without cluttering code with if-else cascades
 * @author les2
 * @source https://stackoverflow.com/questions/2768054/how-to-get-the-first-non-null-value-in-java
 */
public final class NullCoalesce {

    private NullCoalesce(){}

    /**
     * @return the first not-null value
     * @param a
     * @param b
     * @param <T>
     * @return a if a != null, otherwise b.
     */
    public static <T> Optional<T> coalesce(T a, T b) {
        return a != null ? ofNullable(a) : ofNullable(b);
    }

    public static <T> Optional<T> coalesce(T a, T b, T c) {
        return a != null ? ofNullable(a) : coalesce(b,c);
    }

    public static <T> Optional<T> coalesce(T a, T b, T c, T d) {
        return a != null ? ofNullable(a) : coalesce(b,c,d);
    }

}
